=== modified file 'CMakeLists.txt'
--- CMakeLists.txt	2012-11-25 07:04:11 +0000
+++ CMakeLists.txt	2012-11-27 01:23:18 +0000
@@ -6,7 +6,7 @@
 cmake_minimum_required(VERSION 2.8)
 
 set(DISABLE_XFS_REALTIME FALSE CACHE BOOL "Disable support of RealTime XFS partition")
-
+set(USE_CUSTOM_MEMCPY FALSE CACHE BOOL "Use custom memcpy routine instead of stanadrd")
 
 include(CheckIncludeFiles)
 check_include_files("linux/falloc.h" HAVE_LINUX_FALLOC_H)
@@ -25,8 +25,14 @@
 
 add_definitions("-fPIC --std=c99 -Wall -O2 -pthread")
 
-set(HEADERS fastwriter.h sysinfo.h default.h private.h)
-add_library(fastwriter SHARED fastwriter.c sysinfo.c default.c memcpy.c) 
+if (USE_CUSTOM_MEMCPY)
+    set(HEADERS fastwriter.h sysinfo.h default.h private.h memcpy.h)
+    add_library(fastwriter SHARED fastwriter.c sysinfo.c default.c memcpy.c) 
+else (USE_CUSTOM_MEMCPY)
+    set(HEADERS fastwriter.h sysinfo.h default.h private.h)
+    add_library(fastwriter SHARED fastwriter.c sysinfo.c default.c) 
+endif (USE_CUSTOM_MEMCPY)
+
 
 set_target_properties(fastwriter PROPERTIES
     VERSION ${FASTWRITER_VERSION}

=== modified file 'config.h.in'
--- config.h.in	2012-03-08 20:26:06 +0000
+++ config.h.in	2012-11-27 01:23:18 +0000
@@ -1,2 +1,3 @@
 #cmakedefine HAVE_LINUX_FALLOC_H
-#cmakedefine DISABLE_XFS_REALTIME
\ No newline at end of file
+#cmakedefine DISABLE_XFS_REALTIME
+#cmakedefine USE_CUSTOM_MEMCPY

=== modified file 'fastwriter.c'
--- fastwriter.c	2012-11-25 07:04:11 +0000
+++ fastwriter.c	2012-11-27 01:23:18 +0000
@@ -15,11 +15,16 @@
 
 #include <fcntl.h>
 
-
 #include "private.h"
 #include "default.h"
 #include "sysinfo.h"
-#include "memcpy.h"
+
+#ifdef USE_CUSTOM_MEMCPY
+# include "memcpy.h"
+#else /* USE_CUSTOM_MEMCPY */
+# define fast_memcpy memcpy
+#endif /* USE_CUSTOM_MEMCPY */
+
 
 fastwriter_t *fastwriter_init(const char *fs, fastwriter_flags_t flags) {
     fastwriter_t *ctx;

